Installation
============

Invenio-SAML is on PyPI so all you need is:

.. code-block:: console

   $ pip install invenio-saml


Make sure you have installed in your system: 

.. code-block:: console

   libxml2-dev libxmlsec1-dev
